@@ -103,12 +103,13 @@ class DiagramTreeBuilder:
                     if node not in self.diagram.nodes:
                         self.diagram.nodes.append(node)
 
-                subnetwork = Network.create_anonymous([nodes[0]])
-                self.diagram.networks.append(subnetwork)
+                if len(nodes[0].networks) == 0:
+                    nw = Network.create_anonymous([nodes[0]])
+                    self.diagram.networks.append(nw)
 
                 for i in range(len(nodes) - 1):
-                    subnetwork = Network.create_anonymous(nodes[i:i + 2])
-                    self.diagram.networks.append(subnetwork)
+                    nw = Network.create_anonymous(nodes[i:i + 2], stmt.attrs)
+                    self.diagram.networks.append(nw)
 
             elif isinstance(stmt, diagparser.DefAttrs):
                 self.diagram.set_attributes(stmt.attrs)
@@ -176,8 +177,13 @@ class DiagramLayoutManager:
                 if layouted:
                     layouted.sort(lambda a, b: cmp(a.xy.x, b.xy.x))
                     basenode = min(layouted)
+                    commonnw = set(basenode.networks) & set(node.networks)
+
                     if basenode.xy.y == y1:
                         starts = basenode.xy.x + 1
+                    elif commonnw and \
+                         list(commonnw)[0].hidden == True:
+                        starts = basenode.xy.x
                     else:
                         starts = basenode.xy.x + 1 - len(nodes)
 
@@ -237,5 +243,21 @@ class ScreenNodeBuilder:
 
         diagram = DiagramTreeBuilder().build(tree)
         DiagramLayoutManager(diagram).run()
+        diagram = klass.update_network_status(diagram)
+
+        return diagram
+
+    @classmethod
+    def update_network_status(klass, diagram):
+        for node in diagram.nodes:
+            above = [nw for nw in node.networks  if nw.xy.y <= node.xy.y]
+            if len(above) > 1 and [nw for nw in above  if nw.hidden]:
+                for nw in above:
+                    nw.hidden = False
+
+            below = [nw for nw in node.networks  if nw.xy.y > node.xy.y]
+            if len(below) > 1 and [nw for nw in below  if nw.hidden]:
+                for nw in below:
+                    nw.hidden = False
 
         return diagram
